@@ -8,6 +8,7 @@ def get_start_end_index(achievement, rel_string, case_insensitive=False):
         matched = re.search(rel_string, achievement)
     if matched is None:
         warnings.warn(rel_string + "\nnot found in: \n" + achievement)
+        return {"start_index": -1, "end_index": -1, "repl": rel_string}
     return {"start_index": matched.regs[0][0], "end_index": matched.regs[0][1], "repl": rel_string}
 
 def get_all_start_end_indexes(original_text: str, to_replace: list,
@@ -41,13 +42,15 @@ def inject_strings_from_index_info(index_info, output, start_hooks, end_hooks):
     end_index_counter = 0
     for counter, i in enumerate(index_info['flat_index']):
         if i in index_info['end_indexes']:
-            output = inject_string(
-                output, index_info['sorted_end_hooks'][end_index_counter], i, i)
+            if i != -1:
+                output = inject_string(
+                    output, index_info['sorted_end_hooks'][end_index_counter], i, i)
             index_info['end_indexes'].remove(i)
             end_index_counter += 1
         elif i in index_info['start_indexes']:
-            output = inject_string(
-                output, index_info['sorted_start_hooks'][start_index_counter], i, i)
+            if i != -1:
+                output = inject_string(
+                    output, index_info['sorted_start_hooks'][start_index_counter], i, i)
             index_info['start_indexes'].remove(i)
             start_index_counter += 1
     return output
